
function [f] = cell_dCdT_wt(t,c,O2,x_AtC);

%%
% FUNCTION cell_dCdT_wt: computes the derivatives for Beard's
%   model of oxidative phosphorylation in healthy subjects
%
% INPUTS: 
%   t      -           time (not used)
%   c      -           vector of state variables
%   O2     -           oxygen concentration (M) - Attn: M == mol (l water)^{-1})
%   x_AtC  -           ATP consumption parameter (mol s^{-1} (l cell)^{-1})
%
% OUTPUTS:
%   f      -           vector of time derivatives of concentrations
%%

% -------------------------------------------------------------------------
% Step 1. Setting parameters

% Fixed parameters: 
%% physicochemical parameters
RT = 2.5775;                    % gas constant times temperature (kJ mol^{-1})
F = 0.096484;                   % Faraday's constant (kJ mol^{-1} mV^{-1})
dG_C1o = -69.37;                % standard free energy, complex I (kJ mol^{-1})
dG_C3o = -32.53;                % standard free energy, complex III (kJ mol^{-1})
dG_C4o = -122.94;               % standard free energy, complex IV (kJ mol^{-1})
dG_F1o = 36.03;                 % standard free energy, F1Fo-ATPase  (kJ mol^{-1})
n_A = 3.0;                      % proton stoich. coef. for F1Fo-ATPase (unitless)

%% fixed concentrations
pH_c = 7.0;                     % cytosol pH
H_c = 10^(-pH_c);               % H+ concentration in cytoplasm (mol (l cytolasm water)^{-1})
K_c = 150.0e-3;                 % K+ concentration in cytoplasm (mol (l cytolasm water)^{-1})

%% fixed concentration pools
Ctot   = 2.70e-3;               % total cytochrom C concentration (mol (l IM water)^{-1})
Qtot   = 1.35e-3;               % total ubiquinol concentration - Q+QH2 (mol (l matrix water)^{-1})
CRtot  = 42.7e-3;               % total creatine concentration - Cr+PCr (mol (l cytoplasm water)^{-1})
NADtot = 2.97e-3;               % total matrix NAD(H) concentration - NAD+NADH (mol (l matrix water)^{-1})

%% binding constants
k_dHPi  = 10^(-6.75);           % H-Pi binding constant (M)
k_dHatp = 10^(-6.48);           % H-ATP binding constant (M)
k_dHadp = 10^(-6.29);           % H-ADP binding constant (M)
K_DT = 24e-6;                   % Mg-ATP binding constant (M)
K_DD = 347e-6;                  % Mg-ADP binding constant (M)
K_AK = 0.4331;                  % adenylate kinase equilibrium constant (unitless)
K_CK = 1.66e9;                  % creatine kinase equilibrium constant (M)

%% structure/Volume parameters
W_m = 0.664*1.09;               % mitochondrial water space (ml water / ml mito) [Vinnakota & Bassingthwaighte]
W_x = 0.9*W_m;                  % Matrix water space (ml water / ml mito)
W_i = 0.1*W_m;                  % IM water space (ml water / ml mito)
Vmito = 0.056;                  % mitochondrial volume (ml mito / ml cell)
Vcyto = 0.894;                  % cytoplasm volume(ml cyto / ml cell)
Rm_cyto = Vmito / Vcyto;        % Volume ratio of mito volume to cytoplasm volume
Rm_cell = Vmito;                % Volume ratio of mito volume to cell volume
Rc_cell = Vcyto;                % Volume ratio of cytosol volume to cell volume
W_c = 0.807*1.044;              % cytosol water space (ml water / ml cytosol) [Vinnakota & Bassingthwaighte]
gamma  = 5.99;                  % mito membrane area per cell volume (micron^{-1})


% Adjustable parameters:
% (Attention: M == mol (l water)^{-1})
k_Pi1  = 0.1553e-3;             % dehydrogenase model parameter (M)
k_Pi2  = 0.8222e-3;             % dehydrogenase model parameter (M)
k_Pi3  = 0.3601e-3;             % complex III/Pi model parameter (M)
k_Pi4  = 5.651e-3;              % complex III/Pi model parameter (M)
k_PiH  = 0.2542e-3;             % H+/Pi- co-transport parameter (M)
r      = 4.559;                 % dehydrogenase model parameter (unitless)
x_DH   = 0.0866;                % dehydrogenase activity (mol s^{-1} M^{-1} (l mito)^{-1}) 
x_C1   = 4405;                  % complex I activity (mol s^{-1} M^{-2} (l mito)^{-1})
x_C3   = 4.887;                 % complex III activity (mol s^{-1} M^{-3/2} (l mito)^{-1})
x_C4   = 6.766e-5;              % complex IV activity (mol s^{-1} M^{-1} (l mito)^{-1})
x_F1   = 1000.0;                % F1Fo-ATPase activity (mol s^{-1} M^{-1} (l mito)^{-1})
x_ANT  = 0.008123;              % ANT activity (mol s^{-1}(l mito)^{-1})
x_Pi1  = 3.850e5;               % H+/Pi- co-transport activity (mol s^{-1} M^{-1} (l mito)^{-1}) 
x_KH   = 5.651e7;               % K+/H+ antiporter activity (mol s^{-1} M^{-2} (l mito)^{-1})
x_Hle  = 200.0;                 % proton leak activity (mol s^{-1} M^{-1} mV^{-1}(l mito)^{-1})
x_K    = 0;                     % passive potassium transport activity (mol s^{-1} M^{-1} (l mito)^{-1})

% Other parameters:
k_O2   = 1.2e-4;                % kinetic constant for complex IV (M)
k_mADP = 3.5e-6;                % ANT Michaelis-Menton constant (M)
x_buff = 100;                   % matrix buffering coefficient (M^{-1})
x_AK   = 1e7;                   % adenylate kinase activity (M s^{-1} M^{-2})
x_CK   = 1e7;                   % creatine kinase activity (M s^{-1} M^{-2})
x_MgA  = 1e7;                   % Mg2+ binding activity (M s^{-1} M^{-2})
x_A    = 85;                    % mito. outer membrane permeability to nucleotides (micron s^{-1})
x_Pi2  = 327;                   % mito. outer membrane permeability to inorgainic phosphate (micron s^{-1})

% Concentration state variables:
pH_x   = c(1);                  % pH value in matrix
H_x    = 10^(-pH_x);            % H+ concentration in matrix (mol (l matrix water)^{-1})
K_x    = c(2);                  % K_x    (mol (l matrix water)^{-1})
Mg_x   = c(3);                  % Mg_x   (mol (l matrix water)^{-1})
NADH_x = c(4);                  % NADH_x (mol (l matrix water)^{-1})
Q      = c(5);                  % Q      (mol (l matrix water)^{-1})
Cox    = c(6);                  % Cox    (mol (l matrix water)^{-1})
ATP_x  = c(7);                  % ATP_x  (mol (l matrix water)^{-1})
ADP_x  = c(8);                  % ADP_x  (mol (l matrix water)^{-1})
ATP_mx = c(9);                  % ATP_mx (mol (l matrix water)^{-1})
ADP_mx = c(10);                 % ADP_mx (mol (l matrix water)^{-1})
Pi_x   = c(11);                 % Pi_x   (mol (l matrix water)^{-1})
ATP_i  = c(12);                 % ATP_i  (mol (l IM water)^{-1})
ADP_i  = c(13);                 % ADP_i  (mol (l IM water)^{-1})
AMP_i  = c(14);                 % AMP_i  (mol (l IM water)^{-1})
ATP_mi = c(15);                 % ATP_mi (mol (l IM water)^{-1})
ADP_mi = c(16);                 % ADP_mi (mol (l IM water)^{-1})
Pi_i   = c(17);                 % Pi_i   (mol (l IM water)^{-1})
Mg_i   = c(18);                 % Mg_i   (mol (l IM water)^{-1})
ATP_c  = c(19);                 % ATP_c  (mol (l cell water)^{-1})
ADP_c  = c(20);                 % ADP_c  (mol (l cell water)^{-1})
AMP_c  = c(21);                 % AMP_c  (mol (l cell water)^{-1})
ATP_mc = c(22);                 % ATP_mc (mol (l cell water)^{-1})
ADP_mc = c(23);                 % ADP_mc (mol (l cell water)^{-1})
Pi_c   = c(24);                 % Pi_c   (mol (l cell water)^{-1})
Mg_c   = c(25);                 % Mg_c   (mol (l cell water)^{-1})
PCr_c  = c(26);                 % PCr_c  (mol (l cell water)^{-1})
dPsi   = c(27);                 % dPsi   (mV)

% Other concentrations computed from the state variables:
NAD_x  = NADtot - NADH_x;
QH2    = Qtot - Q;
Cred   = Ctot - Cox;
ATP_fx = ATP_x - ATP_mx;
ADP_fx = ADP_x - ADP_mx;
ATP_fi = ATP_i - ATP_mi;
ADP_fi = ADP_i - ADP_mi;
ATP_fc = ATP_c - ATP_mc;
ADP_fc = ADP_c - ADP_mc;
Cr_c   = CRtot - PCr_c;

% K, H in IM space (assuming mito. outer membrance is permeable)
H_i  = H_c;
K_i  = K_c;

% Membrane proton motive force:
dG_H = F*dPsi + RT*log(H_i/H_x);

% Computing the standard free energy of reactions under certain H_x
dG_C1op = dG_C1o - 1*RT*log(H_x/1e-7); % complex I
dG_C3op = dG_C3o + 2*RT*log(H_x/1e-7); % complex III
dG_C4op = dG_C4o - 2*RT*log(H_x/1e-7); % complex IV


% -------------------------------------------------------------------------
% Step 2. Computing model fluxes

% mitochondrial dehydrogenase (mol s^{-1} (l mito)^{-1})
J_DH = x_DH*(r*NAD_x-NADH_x)*((1+Pi_x/k_Pi1)/(1+Pi_x/k_Pi2));  

% complex I (mol s^{-1} (l mito)^{-1})
J_C1 = x_C1*( exp(-(dG_C1op+4*dG_H)/RT)*NADH_x*Q - NAD_x*QH2 );

% complex III (mol s^{-1} (l mito)^{-1})
J_C3 = x_C3*((1+Pi_x/k_Pi3)/(1+Pi_x/k_Pi4))*(exp(-(dG_C3op+4*dG_H-2*F*dPsi)/(2*RT))*Cox*sqrt(QH2) - Cred*sqrt(Q) );

% complex IV (mol s^{-1} (l mito)^{-1})
J_C4 = x_C4*(O2/(O2+k_O2))*(Cred/Ctot)*( exp(-(dG_C4op+2*dG_H)/(2*RT))*Cred*(O2^0.25) - Cox*exp(F*dPsi/RT) );

% F1Fo-ATPase (mol s^{-1} (l mito)^{-1})
J_F1   = x_F1*( exp(-(dG_F1o-n_A*dG_H)/RT)*(K_DD/K_DT)*ADP_mx*Pi_x - ATP_mx );

% adenine nucleotide translocase (mol s^{-1} (l mito)^{-1})
Psi_x = -0.65*dPsi;               % inner electrostatic membrance potential 
Psi_i = +0.35*dPsi;               % outer electrostatic membrance potential
if (ADP_fi > 1e-9) || (ATP_fi > 1e-9)
  J_ANT  = x_ANT*( ADP_fi/(ADP_fi+ATP_fi*exp(-F*Psi_i/RT)) - ADP_fx/(ADP_fx+ATP_fx*exp(-F*Psi_x/RT)) )*(ADP_fi/(ADP_fi+k_mADP));
else
  J_ANT  = 0;
end

% phosphate-hydrogen co-transporter (mol s^{-1} (l mito)^{-1})
H2PIi = Pi_i*H_i/(H_i+k_dHPi);    % hydrogen binding in IM space
H2PIx = Pi_x*H_x/(H_x+k_dHPi);    % hydrogen binding in matrix
J_Pi1 = x_Pi1*(H_i*H2PIi - H_x*H2PIx)/(H2PIi+k_PiH);

% proton leak (mol s^{-1} (l mito)^{-1})
if abs(dPsi) > 1e-6
  J_Hle = x_Hle*dPsi*(H_i*exp(F*dPsi/RT)-H_x)/(exp(F*dPsi/RT)-1);
else
  J_Hle = x_Hle*RT*(H_i-H_x)/F;
end

% mitochondrial K+/H+ exchanger (mol s^{-1} (l mito)^{-1})
J_KH   = x_KH*( K_i*H_x - K_x*H_i );

% passive potassium transport (mol s^{-1} (l mito)^{-1})
if abs(dPsi) > 1e-6
  J_K   = x_K*dPsi*(K_i*exp(F*dPsi/RT)-K_x)/(exp(F*dPsi/RT)-1);
else
  J_K   = x_K*RT*(K_i-K_x)/F;
end

% adenylate kinase
J_AKi  = x_AK*( K_AK*ADP_i*ADP_i - AMP_i*ATP_i );   % in IM space (mol s^{-1} (l mito)^{-1})
J_AKe  = x_AK*( K_AK*ADP_c*ADP_c - AMP_c*ATP_c );   % in cytoplasm (mol s^{-1} (l cytoplasm)^{-1})

% flux across outer membrance
J_AMP  = gamma*x_A*(AMP_c-AMP_i);                   % AMP transport (mol s^{-1} (l mito)^{-1})
J_ADP  = gamma*x_A*(ADP_c-ADP_i);                   % ADP transport (mol s^{-1} (l mito)^{-1})
J_ATP  = gamma*x_A*(ATP_c-ATP_i);                   % ATP transport (mol s^{-1} (l mito)^{-1})
J_Pi2  = gamma*x_Pi2*(Pi_c-Pi_i);                   % Phosphate transport (mol s^{-1} (l mito)^{-1})

% magnesium binding fluxes
J_MgATPx = x_MgA*(ATP_fx*Mg_x-K_DT*ATP_mx);         % in matrix (mol s^{-1} (l mito)^{-1})
J_MgADPx = x_MgA*(ADP_fx*Mg_x-K_DD*ADP_mx);         % in matrix (mol s^{-1} (l mito)^{-1})
J_MgATPi = x_MgA*(ATP_fi*Mg_i-K_DT*ATP_mi);         % in IM space (mol s^{-1} (l mito)^{-1})
J_MgADPi = x_MgA*(ADP_fi*Mg_i-K_DD*ADP_mi);         % in IM space (mol s^{-1} (l mito)^{-1})
J_MgATPe = x_MgA*(ATP_fc*Mg_c-K_DT*ATP_mc);         % in cytoplasm (mol s^{-1} (l cytoplasm)^{-1})
J_MgADPe = x_MgA*(ADP_fc*Mg_c-K_DD*ADP_mc);         % in cytoplasm (mol s^{-1} (l cytoplasm)^{-1})

% ATP consumption rate in cytoplasm (mol s^{-1} (l mito)^{-1})
J_AtC  = x_AtC;

% creatine kinase flux in cytoplasm (mol s^{-1} (l mito)^{-1})
J_CKe  = x_CK*( K_CK*ADP_c*PCr_c*H_c - ATP_c*Cr_c );


% -------------------------------------------------------------------------
% Step 3. Computing time derivatives of state variables
f(1)  = -(1/2.303*x_buff)*( +1*J_DH - (4+1)*J_C1 - (4-2)*J_C3 - ...
                            (2+2)*J_C4 + (n_A-1)*J_F1 + 2*J_Pi1 + ...
                            J_Hle - J_KH ) / W_x;                 % dH_x/dt
f(2)  = (J_KH + J_K)/W_x;                                         % dK_x/dt
f(3)  = (-J_MgATPx - J_MgADPx)/W_x;                               % dMg_x/dt
f(4)  = (+J_DH - J_C1)/W_x;                                       % dNADH/dt
f(5)  = -(+J_C1 - J_C3)/W_x;                                      % dQ/dt
f(6)  = -(+2*J_C3 - 2*J_C4)/W_i;                                  % dCox/dt
f(7)  = (+J_F1 - J_ANT)/W_x;                                      % dATP_x/dt
f(8)  = (-J_F1 + J_ANT)/W_x;                                      % dADP_x/dt
f(9)  = (J_MgATPx)/W_x;                                           % dATP_mx/dt
f(10) = (J_MgADPx)/W_x;                                           % dADP_mx/dt
f(11) = (-J_F1 + J_Pi1)/W_x;                                      % dPi_x/dt
f(12) = (+J_ATP + J_ANT + J_AKi)/W_i;                             % dATP_i/dt
f(13) = (+J_ADP - J_ANT - 2*J_AKi)/W_i;                           % dADP_i/dt
f(14) = (+J_AMP + J_AKi)/W_i;                                     % dAMP_i/dt
f(15) = (J_MgATPi)/W_i;                                           % dATP_mi/dt
f(16) = (J_MgADPi)/W_i;                                           % dADP_mi/dt
f(17) = (-J_Pi1 + J_Pi2)/W_i;                                     % dPi_i/dt
f(18) = (-J_MgATPi - J_MgADPi)/W_i;                               % dMg_i/dt
f(19) = (-J_ATP*Rm_cyto + J_AKe - J_AtC/Rc_cell + J_CKe)/W_c;     % dATP_c/dt
f(20) = (-J_ADP*Rm_cyto - 2*J_AKe + J_AtC/Rc_cell - J_CKe)/W_c;   % dADP_c/dt
f(21) = (-J_AMP*Rm_cyto + J_AKe)/W_c;                             % dAMP_c/dt
f(22) = (+J_MgATPe)/W_c;                                          % dATP_mc/dt
f(23) = (+J_MgADPe)/W_c;                                          % dADP_mc/dt
f(24) = (-J_Pi2*Rm_cyto + J_AtC/Rc_cell)/W_c;                     % dPi_c/dt
f(25) = (-J_MgATPe - J_MgADPe)/W_c;                               % dMg_c/dt
f(26) = (-J_CKe)/W_c;                                             % dPCr_c/dt
f(27) = (1.48e5)*( 4*J_C1 + 2*J_C3 + 4*J_C4 - n_A*J_F1 - J_ANT - ...
                   J_Hle - J_K );                                 % dd_Psi/dt

% convert 1x27 vector to 27x1 one
f = f';


