%
% This syntax is to use Beard's computational model of mitochondrial 
% oxidative phosphorylation (Beard, 2005) to predict experimental 31P-NMR data  
% from 20 healthy volunteers (Jeneson et al., 1995). 
%
% Written By Daniel A. Beard, Department of Physiology, Medical College of
% Wisconsin, Milwaukee, Wisconsin (2006)

% Reference: Oxidative ATP Sythesis in Skeletal Muscle is Controlled by
% Substrate Feedback. Fan Wu, Jeroen A.L. Jeneson, and Daniel A. Beard.
% (Submitted)

% -------------------------------------------------------------------------
% Step 1. Loading experimental data ans setting parameters

% Experimental 31P_NMR data
load data_WT;                                               % loading .mat file containing experimental data
Pratio_exp = data_WT(:,1);                                  % power output ratio (unitless)
% convert Pratio into ATPase flux, P/Pmax in [0.65 0] change linearly ...
% with ATPase flux in [0.22 8e-3] (mols^{-1} (l cell water)^{-1}), i.e.,
% (0.18535-6.74e-3) (mol s^{-1} (l cell)^{-1})
Jp_exp = (Pratio_exp * (0.18535-6.74e-3)/0.65 + 6.74e-3)/1e3; % ATPase flux(mol s^{-1} (l cell)^{-1})
ADP_exp = data_WT(:,2)*1e-6;                                % ADP concentration (mol (l cell water)^{-1})
dG_ATP_exp = data_WT(:,3);                                  % Gibbs energy of ATP hydrolysis (kJ mol^{-1})
PI_exp = data_WT(:,4)*1e-3;                                 % Inorganic phosphate concentration (mol (l cell water)^{-1})
 
% Initial Concentrations of state variables:
%% Fixed concentration pools
Ctot   = 2.70e-3;               % total cytochrom C concentration (mol (l IM water)^{-1})
Qtot   = 1.35e-3;               % total ubiquinol concentration - Q+QH2 (mol (l matrix water)^{-1})
CRtot  = 42.7e-3;               % total creatine concentration - Cr+PCr (mol (l cytoplasm water)^{-1})

%% Model variables
Co(1)  = 7.0;                   % pH value in matrix
Co(2)  = 0.14661;               % K_x    (mol (l matrix water)^{-1})
Co(3)  = 1.0229e-3;             % Mg_x   (mol (l matrix water)^{-1}) 
Co(4)  = 0.0015723;             % NADH_x (mol (l matrix water)^{-1})
Co(5)  = Qtot/2;                % Q      (mol (l matrix water)^{-1})
Co(6)  = Ctot/2;                % Cox    (mol (l matrix water)^{-1})
Co(7)  = 0.0026657;             % ATP_x  (mol (l matrix water)^{-1})
Co(8)  = 0.0073343;             % ADP_x  (mol (l matrix water)^{-1})
Co(9)  = 0.0026046;             % ATP_mx (mol (l matrix water)^{-1})
Co(10) = 0.0054765;             % ADP_mx (mol (l matrix water)^{-1})
Co(11) = 0.1720e-3;             % Pi_x   (mol (l matrix water)^{-1})
Co(12) = 0.0065339;             % ATP_i  (mol (l IM water)^{-1}) 
Co(13) = 6.5773e-5;             % ADP_i  (mol (l IM water)^{-1}) 
Co(14) = 2.8837e-7;             % AMP_i  (mol (l IM water)^{-1}) 
Co(15) = 0.0063812;             % ATP_mi (mol (l IM water)^{-1}) 
Co(16) = 4.8866e-5;             % ADP_mi (mol (l IM water)^{-1}) 
Co(17) = 0.1720e-3;             % Pi_i   (mol (l IM water)^{-1}) 
Co(18) = 0.0010029;             % Mg_i   (mol (l IM water)^{-1}) 
Co(19) = 0.0081312;             % ATP_c  (mol (l cell water)^{-1}) 
Co(20) = 6.8500e-5;             % ADP_c  (mol (l cell water)^{-1}) 
Co(21) = 3.0911e-7;             % AMP_c  (mol (l cell water)^{-1}) 
Co(22) = 0.0079786;             % ATP_mc (mol (l cell water)^{-1}) 
Co(23) = 5.1958e-5;             % ADP_mc (mol (l cell water)^{-1}) 
% Co(24) = 12e-3;                 % Pi_c   (mol (l cell water)^{-1})
Co(24) = 8.7702e-3;             % Pi_c   (mol (l cell water)^{-1}) 
Co(25) = 0.001003;              % Mg_c   (mol (l cell water)^{-1}) 
% Co(26) = 0.50*CRtot;            % PCr_c  (mol (l cell water)^{-1})
Co(26) = 23.589e-3;             % PCr_c  (mol (l cell water)^{-1}) 
Co(27) = 166.67;                % dPsi   (mV)


% Computing value of TPP
Vmito = 0.056;                  % mitochondrial volume(ml mito / ml cell)
Vcyto = 0.894;                  % cytoplasm volume (ml cyto / ml cell)
W_c = 0.807*1.044;              % cytosol water space (ml water / ml cytosol) [Vinnakota & Bassingthwaighte]
W_m = 0.664*1.09;               % mitochondrial water space (ml water / ml mito) [Vinnakota & Bassingthwaighte]
W_x = 0.9*W_m;                  % Matrix water space (ml water / ml mito)
W_i = 0.1*W_m;                  % IM water space (ml water / ml mito)
% TPP = [Vcyto*W_c*(2[ATP]_c+[ADP]_c+[Pi]_c+[CrP]_c)+...
%        Vmito*W_i*(2[ATP]_i+[ADP]_i+[Pi]_i+...
%        Vmito*W_x*([ATP]_x+[Pi]_x)]*1e3 (mmol (l cell)^{-1})
TPP = (Vcyto*W_c*(2*Co(19)+Co(20)+Co(24)+Co(26))*1e3 + ...
Vmito*W_i*(2*Co(12)+Co(13)+Co(17))*1e3 + ...
Vmito*W_x*(Co(7)+Co(11))*1e3)


% -------------------------------------------------------------------------
% Step 2. Generating model-based predictions 

% Carrying out simulation to a steady state at zero ATP consumption rate
RT = 2.5775;                    % Gas constant times temperature (kJ mol^{-1})
x_AtC = 0.0e-4;                 % ATP consumption rate (mol (l cell water)^{-1})
O2  = 3.48e-5;                  % Oxygen concentration (M)  (Attn: M == mol (l water)^{-1})
% Calling the Matlab ODE solver
[t,C] = ode15s(@cell_dCdT_wt,[0 1000],Co,[],O2,x_AtC);

% Displaying steady-state PCr_c/ATP_c(unitless), Pi_c (mM), and Mg_c(mM)
[C(end,26)/C(end,19) C(end,24)*1e3 C(end,25)*1e3]

% Carrying out simulations in a loop to reach steady states with varying 
% ATP consumption rate
for i = 1:81
  % Varying ATP consumption rate (mol (l cell water)^{-1})
  x_AtC_wt(i) = ((i-1)/80)*(4e-4);
  
  % Calling the ODE solver at a given ATP consumption rate
  [t,C] = ode15s(@cell_dCdT_wt,[0 1000],C(end,:),[],O2,x_AtC_wt(i));
  
  % Retrieve state variables at the steady state
  ATP_wt(i) = C(end,19);              % ATP_c (mol (l cell water)^{-1})
  ADP_wt(i) = C(end,20);              % ADP_c (mol (l cell water)^{-1})
  fATP_wt(i) = C(end,19)-C(end,22);   % Mg2+ unbound ATP in cytoplasm (fATP_c = ATP_c - ATP_mc)
  fADP_wt(i) = C(end,20)-C(end,23);   % Mg2+ unbound ADP in cytoplasm (fADP_c = ADP_c - ADP_mc)
  Pi_wt(i)  = C(end,24);              % Pi_c (mol (l cell water)^(-1))
  
  % Computing consumption rate of O2 (mol s^{-1} (l cell)^{-1}
  JO2_wt(i) = ox_flux(C(end,:),O2);    
  
  % Computing free energy of ATP hydrolysis 
  dG_fATP_wt(i) = -36.03 + RT*log((fADP_wt(i)*Pi_wt(i))/fATP_wt(i)); 
end


% -------------------------------------------------------------------------
% Step 3. Plotting experimental measurement along with model-based
% predictions for healthy subjects

% Plotting concentrations of ADP_c from the experiments and the model
% against ATP hydrolysis rate
figure(21); clf;
box on; hold on;
% plotting the experimental data points
p = plot(Jp_exp*1e3,ADP_exp*1e3,'ko'); 
% plotting the predicted curve
plot(x_AtC_wt*1e3,ADP_wt*1e3,'k-','linewidth',1.5);
% format the figure
set(p,'linewidth',1.0,'MarkerFaceColor',[0.6 0.6 0.6]);
set(gca,'Fontsize',14); axis([0 0.25 0 0.2]);
set(gca,'XtickLabel',[]);
ylabel('[ADP]_c (mM)');

% Plotting concentrations of Pi_c from the experiments and the model
% against ATP hydrolysis rate
figure(22); clf;
box on; hold on;
% plotting the experimental data points
p = plot(Jp_exp*1e3,PI_exp*1e3,'ko');
% plotting the predicted curve
plot(x_AtC_wt*1e3,Pi_wt*1e3,'k-','linewidth',1.5);
% format the figure
set(p,'linewidth',1.0,'MarkerFaceColor',[0.6 0.6 0.6]);
set(gca,'Fontsize',14); axis([0 0.25 0 25]);
set(gca,'Ytick',0:5:20);
ylabel('[Pi]_c (mM)');
xlabel('ATPase Flux (mmol sec^{-1} (l cell)^{-1})');

% Plotting the free energy of ATP hydrolysis from the experiments and the 
% model against ATP hydrolysis rate
figure(23); clf;
box on; hold on;
% plotting the experimental data points
p = plot(Jp_exp*1e3,dG_ATP_exp,'ko'); 
% plotting the predicted curve
plot(x_AtC_wt*1e3,dG_fATP_wt,'k-','linewidth',1.5);
% format the figure
set(p,'linewidth',1.0,'MarkerFaceColor',[0.6 0.6 0.6]);
set(gca,'Fontsize',14); 
axis([0 0.25 -75 -50]);
ylabel('\DeltaG_{ATP} (kJ/mol)');
xlabel('ATPase Flux (mmol sec^{-1} (l cell)^{-1})');




